class ListViewItem(object,ICloneable,ISerializable):
 """
 Represents an item in a System.Windows.Forms.ListView control.

 

 ListViewItem()

 ListViewItem(text: str)

 ListViewItem(text: str,imageIndex: int)

 ListViewItem(items: Array[str])

 ListViewItem(items: Array[str],imageIndex: int)

 ListViewItem(items: Array[str],imageIndex: int,foreColor: Color,backColor: Color,font: Font)

 ListViewItem(subItems: Array[ListViewSubItem],imageIndex: int)

 ListViewItem(group: ListViewGroup)

 ListViewItem(text: str,group: ListViewGroup)

 ListViewItem(text: str,imageIndex: int,group: ListViewGroup)

 ListViewItem(items: Array[str],group: ListViewGroup)

 ListViewItem(items: Array[str],imageIndex: int,group: ListViewGroup)

 ListViewItem(items: Array[str],imageIndex: int,foreColor: Color,backColor: Color,font: Font,group: ListViewGroup)

 ListViewItem(subItems: Array[ListViewSubItem],imageIndex: int,group: ListViewGroup)

 ListViewItem(text: str,imageKey: str)

 ListViewItem(items: Array[str],imageKey: str)

 ListViewItem(items: Array[str],imageKey: str,foreColor: Color,backColor: Color,font: Font)

 ListViewItem(subItems: Array[ListViewSubItem],imageKey: str)

 ListViewItem(text: str,imageKey: str,group: ListViewGroup)

 ListViewItem(items: Array[str],imageKey: str,group: ListViewGroup)

 ListViewItem(items: Array[str],imageKey: str,foreColor: Color,backColor: Color,font: Font,group: ListViewGroup)

 ListViewItem(subItems: Array[ListViewSubItem],imageKey: str,group: ListViewGroup)
 """
 def BeginEdit(self):
  """
  BeginEdit(self: ListViewItem)

   Places the item text into edit mode.
  """
  pass
 def Clone(self):
  """
  Clone(self: ListViewItem) -> object

  

   Creates an identical copy of the item.

   Returns: An object that represents an item that has the same text,image,and subitems associated with it 

    as the cloned item.
  """
  pass
 def Deserialize(self,*args):
  """
  Deserialize(self: ListViewItem,info: SerializationInfo,context: StreamingContext)

   Deserializes the item.

  

   info: A System.Runtime.Serialization.SerializationInfo that holds the data needed to deserialize the 

    item.

  

   context: A System.Runtime.Serialization.StreamingContext that represents the source and destination of 

    the stream being deserialized.
  """
  pass
 def EnsureVisible(self):
  """
  EnsureVisible(self: ListViewItem)

   Ensures that the item is visible within the control,scrolling the contents of the control,if 

    necessary.
  """
  pass
 def FindNearestItem(self,searchDirection):
  """
  FindNearestItem(self: ListViewItem,searchDirection: SearchDirectionHint) -> ListViewItem

  

   Finds the next item from the System.Windows.Forms.ListViewItem,searching in the specified 

    direction.

  

  

   searchDirection: One of the System.Windows.Forms.SearchDirectionHint values.

   Returns: The System.Windows.Forms.ListViewItem that is closest to the given coordinates,searching in the 

    specified direction.
  """
  pass
 def GetBounds(self,portion):
  """
  GetBounds(self: ListViewItem,portion: ItemBoundsPortion) -> Rectangle

  

   Retrieves the specified portion of the bounding rectangle for the item.

  

   portion: One of the System.Windows.Forms.ItemBoundsPortion values that represents a portion of the item 

    for which to retrieve the bounding rectangle.

  

   Returns: A System.Drawing.Rectangle that represents the bounding rectangle for the specified portion of 

    the item.
  """
  pass
 def GetSubItemAt(self,x,y):
  """
  GetSubItemAt(self: ListViewItem,x: int,y: int) -> ListViewSubItem

  

   Returns the subitem of the System.Windows.Forms.ListViewItem at the specified coordinates.

  

   x: The x-coordinate.

   y: The y-coordinate.

   Returns: The System.Windows.Forms.ListViewItem.ListViewSubItem at the specified x- and y-coordinates.
  """
  pass
 def Remove(self):
  """
  Remove(self: ListViewItem)

   Removes the item from its associated System.Windows.Forms.ListView control.
  """
  pass
 def Serialize(self,*args):
  """
  Serialize(self: ListViewItem,info: SerializationInfo,context: StreamingContext)

   Serializes the item.

  

   info: A System.Runtime.Serialization.SerializationInfo that holds the data needed to serialize the 

    item.

  

   context: A System.Runtime.Serialization.StreamingContext that represents the source and destination of 

    the stream being serialized.
  """
  pass
 def ToString(self):
  """
  ToString(self: ListViewItem) -> str

   Returns: A string that represents the current object.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)

  __new__(cls: type,text: str)

  __new__(cls: type,text: str,imageIndex: int)

  __new__(cls: type,items: Array[str])

  __new__(cls: type,items: Array[str],imageIndex: int)

  __new__(cls: type,items: Array[str],imageIndex: int,foreColor: Color,backColor: Color,font: Font)

  __new__(cls: type,subItems: Array[ListViewSubItem],imageIndex: int)

  __new__(cls: type,group: ListViewGroup)

  __new__(cls: type,text: str,group: ListViewGroup)

  __new__(cls: type,text: str,imageIndex: int,group: ListViewGroup)

  __new__(cls: type,items: Array[str],group: ListViewGroup)

  __new__(cls: type,items: Array[str],imageIndex: int,group: ListViewGroup)

  __new__(cls: type,items: Array[str],imageIndex: int,foreColor: Color,backColor: Color,font: Font,group: ListViewGroup)

  __new__(cls: type,subItems: Array[ListViewSubItem],imageIndex: int,group: ListViewGroup)

  __new__(cls: type,text: str,imageKey: str)

  __new__(cls: type,items: Array[str],imageKey: str)

  __new__(cls: type,items: Array[str],imageKey: str,foreColor: Color,backColor: Color,font: Font)

  __new__(cls: type,subItems: Array[ListViewSubItem],imageKey: str)

  __new__(cls: type,text: str,imageKey: str,group: ListViewGroup)

  __new__(cls: type,items: Array[str],imageKey: str,group: ListViewGroup)

  __new__(cls: type,items: Array[str],imageKey: str,foreColor: Color,backColor: Color,font: Font,group: ListViewGroup)

  __new__(cls: type,subItems: Array[ListViewSubItem],imageKey: str,group: ListViewGroup)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __str__(self,*args):
  pass
 BackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the background color of the item's text.



Get: BackColor(self: ListViewItem) -> Color



Set: BackColor(self: ListViewItem)=value

"""

 Bounds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the bounding rectangle of the item,including subitems.



Get: Bounds(self: ListViewItem) -> Rectangle



"""

 Checked=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the item is checked.



Get: Checked(self: ListViewItem) -> bool



Set: Checked(self: ListViewItem)=value

"""

 Focused=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the item has focus within the System.Windows.Forms.ListView control.



Get: Focused(self: ListViewItem) -> bool



Set: Focused(self: ListViewItem)=value

"""

 Font=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the font of the text displayed by the item.



Get: Font(self: ListViewItem) -> Font



Set: Font(self: ListViewItem)=value

"""

 ForeColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the foreground color of the item's text.



Get: ForeColor(self: ListViewItem) -> Color



Set: ForeColor(self: ListViewItem)=value

"""

 Group=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the group to which the item is assigned.



Get: Group(self: ListViewItem) -> ListViewGroup



Set: Group(self: ListViewItem)=value

"""

 ImageIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the index of the image that is displayed for the item.



Get: ImageIndex(self: ListViewItem) -> int



Set: ImageIndex(self: ListViewItem)=value

"""

 ImageKey=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the key for the image that is displayed for the item.



Get: ImageKey(self: ListViewItem) -> str



Set: ImageKey(self: ListViewItem)=value

"""

 ImageList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.ImageList that contains the image displayed with the item.



Get: ImageList(self: ListViewItem) -> ImageList



"""

 IndentCount=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of small image widths by which to indent the System.Windows.Forms.ListViewItem.



Get: IndentCount(self: ListViewItem) -> int



Set: IndentCount(self: ListViewItem)=value

"""

 Index=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the zero-based index of the item within the System.Windows.Forms.ListView control.



Get: Index(self: ListViewItem) -> int



"""

 ListView=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.ListView control that contains the item.



Get: ListView(self: ListViewItem) -> ListView



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name associated with this System.Windows.Forms.ListViewItem.



Get: Name(self: ListViewItem) -> str



Set: Name(self: ListViewItem)=value

"""

 Position=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the position of the upper-left corner of the System.Windows.Forms.ListViewItem.



Get: Position(self: ListViewItem) -> Point



Set: Position(self: ListViewItem)=value

"""

 Selected=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the item is selected.



Get: Selected(self: ListViewItem) -> bool



Set: Selected(self: ListViewItem)=value

"""

 StateImageIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the index of the state image (an image such as a selected or cleared check box that indicates the state of the item) that is displayed for the item.



Get: StateImageIndex(self: ListViewItem) -> int



Set: StateImageIndex(self: ListViewItem)=value

"""

 SubItems=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection containing all subitems of the item.



Get: SubItems(self: ListViewItem) -> ListViewSubItemCollection



"""

 Tag=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets an object that contains data to associate with the item.



Get: Tag(self: ListViewItem) -> object



Set: Tag(self: ListViewItem)=value

"""

 Text=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the text of the item.



Get: Text(self: ListViewItem) -> str



Set: Text(self: ListViewItem)=value

"""

 ToolTipText=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the text shown when the mouse pointer rests on the System.Windows.Forms.ListViewItem.



Get: ToolTipText(self: ListViewItem) -> str



Set: ToolTipText(self: ListViewItem)=value

"""

 UseItemStyleForSubItems=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the System.Windows.Forms.ListViewItem.Font,System.Windows.Forms.ListViewItem.ForeColor,and System.Windows.Forms.ListViewItem.BackColor properties for the item are used for all its subitems.



Get: UseItemStyleForSubItems(self: ListViewItem) -> bool



Set: UseItemStyleForSubItems(self: ListViewItem)=value

"""


 ListViewSubItem=None
 ListViewSubItemCollection=None




class DataGridViewCellValueEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.DataGridView.CellValueNeeded and System.Windows.Forms.DataGridView.CellValuePushed events of the System.Windows.Forms.DataGridView control.

 

 DataGridViewCellValueEventArgs(columnIndex: int,rowIndex: int)
 """
 @staticmethod
 def __new__(self,columnIndex,rowIndex):
  """ __new__(cls: type,columnIndex: int,rowIndex: int) """
  pass
 ColumnIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating the column index of the cell that the event occurs for.



Get: ColumnIndex(self: DataGridViewCellValueEventArgs) -> int



"""

 RowIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating the row index of the cell that the event occurs for.



Get: RowIndex(self: DataGridViewCellValueEventArgs) -> int



"""

 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value of the cell that the event occurs for.



Get: Value(self: DataGridViewCellValueEventArgs) -> object



Set: Value(self: DataGridViewCellValueEventArgs)=value

"""





class DebuggerStepThroughAttribute(Attribute,_Attribute):
 """
 Instructs the debugger to step through the code instead of stepping into the code. This class cannot be inherited.

 

 DebuggerStepThroughAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __reduce_ex__(self,*args):
  pass



class BufferedStream(Stream,IDisposable):
 """
 Adds a buffering layer to read and write operations on another stream. This class cannot be inherited.

 

 BufferedStream(stream: Stream)

 BufferedStream(stream: Stream,bufferSize: int)
 """
 def BeginRead(self,buffer,offset,count,callback,state):
  """ BeginRead(self: BufferedStream,buffer: Array[Byte],offset: int,count: int,callback: AsyncCallback,state: object) -> IAsyncResult """
  pass
 def BeginWrite(self,buffer,offset,count,callback,state):
  """ BeginWrite(self: BufferedStream,buffer: Array[Byte],offset: int,count: int,callback: AsyncCallback,state: object) -> IAsyncResult """
  pass
 def CreateWaitHandle(self,*args):
  """
  CreateWaitHandle(self: Stream) -> WaitHandle

  

   Allocates a System.Threading.WaitHandle object.

   Returns: A reference to the allocated WaitHandle.
  """
  pass
 def Dispose(self):
  """ Dispose(self: BufferedStream,disposing: bool) """
  pass
 def EndRead(self,asyncResult):
  """ EndRead(self: BufferedStream,asyncResult: IAsyncResult) -> int """
  pass
 def EndWrite(self,asyncResult):
  """ EndWrite(self: BufferedStream,asyncResult: IAsyncResult) """
  pass
 def Flush(self):
  """
  Flush(self: BufferedStream)

   Clears all buffers for this stream and causes any buffered data to be written to the underlying 

    device.
  """
  pass
 def FlushAsync(self,cancellationToken=None):
  """ FlushAsync(self: BufferedStream,cancellationToken: CancellationToken) -> Task """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def ObjectInvariant(self,*args):
  """
  ObjectInvariant(self: Stream)

   Provides support for a System.Diagnostics.Contracts.Contract.
  """
  pass
 def Read(self,array,offset,count):
  """
  Read(self: BufferedStream,offset: int,count: int) -> (int,Array[Byte])

  

   Copies bytes from the current buffered stream to an array.

  

   offset: The byte offset in the buffer at which to begin reading bytes.

   count: The number of bytes to be read.

   Returns: The total number of bytes read into array. This can be less than the number of bytes requested 

    if that many bytes are not currently available,or 0 if the end of the stream has been reached 

    before any data can be read.
  """
  pass
 def ReadAsync(self,buffer,offset,count,cancellationToken=None):
  """ ReadAsync(self: BufferedStream,buffer: Array[Byte],offset: int,count: int,cancellationToken: CancellationToken) -> Task[int] """
  pass
 def ReadByte(self):
  """
  ReadByte(self: BufferedStream) -> int

  

   Reads a byte from the underlying stream and returns the byte cast to an int,or returns -1 if 

    reading from the end of the stream.

  

   Returns: The byte cast to an int,or -1 if reading from the end of the stream.
  """
  pass
 def Seek(self,offset,origin):
  """
  Seek(self: BufferedStream,offset: Int64,origin: SeekOrigin) -> Int64

  

   Sets the position within the current buffered stream.

  

   offset: A byte offset relative to origin.

   origin: A value of type System.IO.SeekOrigin indicating the reference point from which to obtain the new 

    position.

  

   Returns: The new position within the current buffered stream.
  """
  pass
 def SetLength(self,value):
  """
  SetLength(self: BufferedStream,value: Int64)

   Sets the length of the buffered stream.

  

   value: An integer indicating the desired length of the current buffered stream in bytes.
  """
  pass
 def Write(self,array,offset,count):
  """
  Write(self: BufferedStream,array: Array[Byte],offset: int,count: int)

   Copies bytes to the buffered stream and advances the current position within the buffered stream 

    by the number of bytes written.

  

  

   array: The byte array from which to copy count bytes to the current buffered stream.

   offset: The offset in the buffer at which to begin copying bytes to the current buffered stream.

   count: The number of bytes to be written to the current buffered stream.
  """
  pass
 def WriteAsync(self,buffer,offset,count,cancellationToken=None):
  """ WriteAsync(self: BufferedStream,buffer: Array[Byte],offset: int,count: int,cancellationToken: CancellationToken) -> Task """
  pass
 def WriteByte(self,value):
  """
  WriteByte(self: BufferedStream,value: Byte)

   Writes a byte to the current position in the buffered stream.

  

   value: A byte to write to the stream.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,stream,bufferSize=None):
  """
  __new__(cls: type,stream: Stream)

  __new__(cls: type,stream: Stream,bufferSize: int)
  """
  pass
 CanRead=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the current stream supports reading.



Get: CanRead(self: BufferedStream) -> bool



"""

 CanSeek=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the current stream supports seeking.



Get: CanSeek(self: BufferedStream) -> bool



"""

 CanWrite=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the current stream supports writing.



Get: CanWrite(self: BufferedStream) -> bool



"""

 Length=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the stream length in bytes.



Get: Length(self: BufferedStream) -> Int64



"""

 Position=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the position within the current stream.



Get: Position(self: BufferedStream) -> Int64



Set: Position(self: BufferedStream)=value

"""





class WebProxy(object,IAutoWebProxy,IWebProxy,ISerializable):
 """
 Contains HTTP proxy settings for the System.Net.WebRequest class.

 

 WebProxy()

 WebProxy(Address: Uri)

 WebProxy(Address: Uri,BypassOnLocal: bool)

 WebProxy(Address: Uri,BypassOnLocal: bool,BypassList: Array[str])

 WebProxy(Address: Uri,BypassOnLocal: bool,BypassList: Array[str],Credentials: ICredentials)

 WebProxy(Host: str,Port: int)

 WebProxy(Address: str)

 WebProxy(Address: str,BypassOnLocal: bool)

 WebProxy(Address: str,BypassOnLocal: bool,BypassList: Array[str])

 WebProxy(Address: str,BypassOnLocal: bool,BypassList: Array[str],Credentials: ICredentials)
 """
 @staticmethod
 def GetDefaultProxy():
  """
  GetDefaultProxy() -> WebProxy

  

   Reads the Internet Explorer nondynamic proxy settings.

   Returns: A System.Net.WebProxy instance that contains the nondynamic proxy settings from Internet 

    Explorer 5.5 and later.
  """
  pass
 def GetObjectData(self,*args):
  """
  GetObjectData(self: WebProxy,serializationInfo: SerializationInfo,streamingContext: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo with the data that is needed to 

    serialize the target object.

  

  

   serializationInfo: The System.Runtime.Serialization.SerializationInfo to populate with data.

   streamingContext: A System.Runtime.Serialization.StreamingContext that specifies the destination for this 

    serialization.
  """
  pass
 def GetProxy(self,destination):
  """
  GetProxy(self: WebProxy,destination: Uri) -> Uri

  

   Returns the proxied URI for a request.

  

   destination: The System.Uri instance of the requested Internet resource.

   Returns: The System.Uri instance of the Internet resource,if the resource is on the bypass list; 

    otherwise,the System.Uri instance of the proxy.
  """
  pass
 def IsBypassed(self,host):
  """
  IsBypassed(self: WebProxy,host: Uri) -> bool

  

   Indicates whether to use the proxy server for the specified host.

  

   host: The System.Uri instance of the host to check for proxy use.

   Returns: true if the proxy server should not be used for host; otherwise,false.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,Address: Uri)

  __new__(cls: type,Address: Uri,BypassOnLocal: bool)

  __new__(cls: type,Address: Uri,BypassOnLocal: bool,BypassList: Array[str])

  __new__(cls: type,Address: Uri,BypassOnLocal: bool,BypassList: Array[str],Credentials: ICredentials)

  __new__(cls: type,Host: str,Port: int)

  __new__(cls: type,Address: str)

  __new__(cls: type,Address: str,BypassOnLocal: bool)

  __new__(cls: type,Address: str,BypassOnLocal: bool,BypassList: Array[str])

  __new__(cls: type,Address: str,BypassOnLocal: bool,BypassList: Array[str],Credentials: ICredentials)

  __new__(cls: type,serializationInfo: SerializationInfo,streamingContext: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Address=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the address of the proxy server.



Get: Address(self: WebProxy) -> Uri



Set: Address(self: WebProxy)=value

"""

 BypassArrayList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a list of addresses that do not use the proxy server.



Get: BypassArrayList(self: WebProxy) -> ArrayList



"""

 BypassList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets an array of addresses that do not use the proxy server.



Get: BypassList(self: WebProxy) -> Array[str]



Set: BypassList(self: WebProxy)=value

"""

 BypassProxyOnLocal=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether to bypass the proxy server for local addresses.



Get: BypassProxyOnLocal(self: WebProxy) -> bool



Set: BypassProxyOnLocal(self: WebProxy)=value

"""

 Credentials=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the credentials to submit to the proxy server for authentication.



Get: Credentials(self: WebProxy) -> ICredentials



Set: Credentials(self: WebProxy)=value

"""

 UseDefaultCredentials=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a System.Boolean value that controls whether the System.Net.CredentialCache.DefaultCredentials are sent with requests.



Get: UseDefaultCredentials(self: WebProxy) -> bool



Set: UseDefaultCredentials(self: WebProxy)=value

"""





class DataGridViewAutoSizeColumnModeEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.DataGridView.AutoSizeColumnModeChanged event.

 

 DataGridViewAutoSizeColumnModeEventArgs(dataGridViewColumn: DataGridViewColumn,previousMode: DataGridViewAutoSizeColumnMode)
 """
 @staticmethod
 def __new__(self,dataGridViewColumn,previousMode):
  """ __new__(cls: type,dataGridViewColumn: DataGridViewColumn,previousMode: DataGridViewAutoSizeColumnMode) """
  pass
 Column=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the column with the System.Windows.Forms.DataGridViewColumn.AutoSizeMode property that changed.



Get: Column(self: DataGridViewAutoSizeColumnModeEventArgs) -> DataGridViewColumn



"""

 PreviousMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the previous value of the System.Windows.Forms.DataGridViewColumn.AutoSizeMode property of the column.



Get: PreviousMode(self: DataGridViewAutoSizeColumnModeEventArgs) -> DataGridViewAutoSizeColumnMode



"""





class DatePickerDateValidationErrorEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Controls.DatePicker.DateValidationError event.

 

 DatePickerDateValidationErrorEventArgs(exception: Exception,text: str)
 """
 @staticmethod
 def __new__(self,exception,text):
  """ __new__(cls: type,exception: Exception,text: str) """
  pass
 Exception=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the initial exception associated with the System.Windows.Controls.DatePicker.DateValidationError event.



Get: Exception(self: DatePickerDateValidationErrorEventArgs) -> Exception



"""

 Text=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the text that caused the System.Windows.Controls.DatePicker.DateValidationError event.



Get: Text(self: DatePickerDateValidationErrorEventArgs) -> str



"""

 ThrowException=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether System.Windows.Controls.DatePickerDateValidationErrorEventArgs.Exception should be thrown.



Get: ThrowException(self: DatePickerDateValidationErrorEventArgs) -> bool



Set: ThrowException(self: DatePickerDateValidationErrorEventArgs)=value

"""





class MutexRights(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the access control rights that can be applied to named system mutex objects.

 

 enum (flags) MutexRights,values: ChangePermissions (262144),Delete (65536),FullControl (2031617),Modify (1),ReadPermissions (131072),Synchronize (1048576),TakeOwnership (524288)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 ChangePermissions=None
 Delete=None
 FullControl=None
 Modify=None
 ReadPermissions=None
 Synchronize=None
 TakeOwnership=None
 value__=None




class AnimationException(SystemException,ISerializable,_Exception):
 """ The exception that is thrown when an error occurs while animating a property. """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Clock=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the clock that generates the animated values.



Get: Clock(self: AnimationException) -> AnimationClock



"""

 Property=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the animated dependency property.



Get: Property(self: AnimationException) -> DependencyProperty



"""

 Target=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the animated object.



Get: Target(self: AnimationException) -> IAnimatable



"""





class DataGridHyperlinkColumn(DataGridBoundColumn):
 """
 Represents a System.Windows.Controls.DataGrid column that hosts System.Uri elements in its cells.

 

 DataGridHyperlinkColumn()
 """
 def OnContentBindingChanged(self,*args):
  """
  OnContentBindingChanged(self: DataGridHyperlinkColumn,oldBinding: BindingBase,newBinding: BindingBase)

   Notifies the System.Windows.Controls.DataGrid when the 

    System.Windows.Controls.DataGridHyperlinkColumn.ContentBinding property changes.

  

  

   oldBinding: The previous binding.

   newBinding: The binding that the column has been changed to.
  """
  pass
 ContentBinding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the binding to the text of the hyperlink.



Get: ContentBinding(self: DataGridHyperlinkColumn) -> BindingBase



Set: ContentBinding(self: DataGridHyperlinkColumn)=value

"""

 DataGridOwner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Controls.DataGrid control that contains this column.



"""

 TargetName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of a target window or frame for the hyperlink.



Get: TargetName(self: DataGridHyperlinkColumn) -> str



Set: TargetName(self: DataGridHyperlinkColumn)=value

"""


 DefaultEditingElementStyle=None
 DefaultElementStyle=None
 TargetNameProperty=None




class DrawItemEventArgs(EventArgs):
 """
 Provides data for the DrawItem event.

 

 DrawItemEventArgs(graphics: Graphics,font: Font,rect: Rectangle,index: int,state: DrawItemState)

 DrawItemEventArgs(graphics: Graphics,font: Font,rect: Rectangle,index: int,state: DrawItemState,foreColor: Color,backColor: Color)
 """
 def DrawBackground(self):
  """
  DrawBackground(self: DrawItemEventArgs)

   Draws the background within the bounds specified in the 

    erload:System.Windows.Forms.DrawItemEventArgs.#ctor constructor and with the appropriate color.
  """
  pass
 def DrawFocusRectangle(self):
  """
  DrawFocusRectangle(self: DrawItemEventArgs)

   Draws a focus rectangle within the bounds specified in the 

    erload:System.Windows.Forms.DrawItemEventArgs.#ctor constructor.
  """
  pass
 @staticmethod
 def __new__(self,graphics,font,rect,index,state,foreColor=None,backColor=None):
  """
  __new__(cls: type,graphics: Graphics,font: Font,rect: Rectangle,index: int,state: DrawItemState)

  __new__(cls: type,graphics: Graphics,font: Font,rect: Rectangle,index: int,state: DrawItemState,foreColor: Color,backColor: Color)
  """
  pass
 BackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the background color of the item that is being drawn.



Get: BackColor(self: DrawItemEventArgs) -> Color



"""

 Bounds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the rectangle that represents the bounds of the item that is being drawn.



Get: Bounds(self: DrawItemEventArgs) -> Rectangle



"""

 Font=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the font that is assigned to the item being drawn.



Get: Font(self: DrawItemEventArgs) -> Font



"""

 ForeColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the foreground color of the of the item being drawn.



Get: ForeColor(self: DrawItemEventArgs) -> Color



"""

 Graphics=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the graphics surface to draw the item on.



Get: Graphics(self: DrawItemEventArgs) -> Graphics



"""

 Index=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the index value of the item that is being drawn.



Get: Index(self: DrawItemEventArgs) -> int



"""

 State=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the state of the item being drawn.



Get: State(self: DrawItemEventArgs) -> DrawItemState



"""





class TYPEKIND(Enum,IComparable,IFormattable,IConvertible):
 """
 Use System.Runtime.InteropServices.ComTypes.TYPEKIND instead.

 

 enum TYPEKIND,values: TKIND_ALIAS (6),TKIND_COCLASS (5),TKIND_DISPATCH (4),TKIND_ENUM (0),TKIND_INTERFACE (3),TKIND_MAX (8),TKIND_MODULE (2),TKIND_RECORD (1),TKIND_UNION (7)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 TKIND_ALIAS=None
 TKIND_COCLASS=None
 TKIND_DISPATCH=None
 TKIND_ENUM=None
 TKIND_INTERFACE=None
 TKIND_MAX=None
 TKIND_MODULE=None
 TKIND_RECORD=None
 TKIND_UNION=None
 value__=None




class DataGridViewCellFormattingEventArgs(ConvertEventArgs):
 """
 Provides data for the System.Windows.Forms.DataGridView.CellFormatting event of a System.Windows.Forms.DataGridView.

 

 DataGridViewCellFormattingEventArgs(columnIndex: int,rowIndex: int,value: object,desiredType: Type,cellStyle: DataGridViewCellStyle)
 """
 @staticmethod
 def __new__(self,columnIndex,rowIndex,value,desiredType,cellStyle):
  """ __new__(cls: type,columnIndex: int,rowIndex: int,value: object,desiredType: Type,cellStyle: DataGridViewCellStyle) """
  pass
 CellStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the style of the cell that is being formatted.



Get: CellStyle(self: DataGridViewCellFormattingEventArgs) -> DataGridViewCellStyle



Set: CellStyle(self: DataGridViewCellFormattingEventArgs)=value

"""

 ColumnIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the column index of the cell that is being formatted.



Get: ColumnIndex(self: DataGridViewCellFormattingEventArgs) -> int



"""

 FormattingApplied=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the cell value has been successfully formatted.



Get: FormattingApplied(self: DataGridViewCellFormattingEventArgs) -> bool



Set: FormattingApplied(self: DataGridViewCellFormattingEventArgs)=value

"""

 RowIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the row index of the cell that is being formatted.



Get: RowIndex(self: DataGridViewCellFormattingEventArgs) -> int



"""





class SystemIcons(object):
 """ Each property of the System.Drawing.SystemIcons class is an System.Drawing.Icon object for Windows system-wide icons. This class cannot be inherited. """
 Application=None
 Asterisk=None
 Error=None
 Exclamation=None
 Hand=None
 Information=None
 Question=None
 Shield=None
 Warning=None
 WinLogo=None




class FileLoadException(IOException,ISerializable,_Exception):
 """
 The exception that is thrown when a managed assembly is found but cannot be loaded.

 

 FileLoadException()

 FileLoadException(message: str)

 FileLoadException(message: str,inner: Exception)

 FileLoadException(message: str,fileName: str)

 FileLoadException(message: str,fileName: str,inner: Exception)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def GetObjectData(self,info,context):
  """
  GetObjectData(self: FileLoadException,info: SerializationInfo,context: StreamingContext)

   Sets the System.Runtime.Serialization.SerializationInfo with the file name and additional 

    exception information.

  

  

   info: The System.Runtime.Serialization.SerializationInfo that holds the serialized object data about 

    the exception being thrown.

  

   context: The System.Runtime.Serialization.StreamingContext that contains contextual information about the 

    source or destination.
  """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def ToString(self):
  """
  ToString(self: FileLoadException) -> str

  

   Returns the fully qualified name of the current exception,and possibly the error message,the 

    name of the inner exception,and the stack trace.

  

   Returns: A string containing the fully qualified name of this exception,and possibly the error message,

    the name of the inner exception,and the stack trace,depending on which 

    System.IO.FileLoadException constructor is used.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,message=None,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,inner: Exception)

  __new__(cls: type,message: str,fileName: str)

  __new__(cls: type,message: str,fileName: str,inner: Exception)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 FileName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the file that causes this exception.



Get: FileName(self: FileLoadException) -> str



"""

 FusionLog=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the log file that describes why an assembly load failed.



Get: FusionLog(self: FileLoadException) -> str



"""

 Message=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the error message and the name of the file that caused this exception.



Get: Message(self: FileLoadException) -> str



"""






# -*- coding: utf-8 -*-
"""Handles http api routing and serving with usage similar to flask."""
#pylint: disable=import-error,invalid-name,broad-except,dangerous-default-value,missing-docstring
from pyrevit import HOST_APP, PyRevitException
from pyrevit.api import DB, UI
from pyrevit.labs import TargetApps
from pyrevit.coreutils import envvars
from pyrevit.coreutils.logger import get_logger
from pyrevit.userconfig import user_config
from pyrevit.loader import sessioninfo

# types to be exported
from pyrevit.routes.server.base import \
    OK, ACCEPTED, INTERNAL_SERVER_ERROR, NO_CONTENT
from pyrevit.routes.server.base import Request, Response

from pyrevit.routes.server import serverinfo
from pyrevit.routes.server import router
from pyrevit.routes.server import server


__all__ = (
    'OK', 'ACCEPTED', 'INTERNAL_SERVER_ERROR', 'NO_CONTENT',
    'Request', 'Response',
    'init', 'activate_server', 'deactivate_server', 'get_active_server',
    'make_response', 'get_routes', 'add_route', 'remove_route',
    )


mlogger = get_logger(__name__)


def init():
    """Initialize routes. Reset all registered routes and shutdown servers."""
    # clear all routes
    router.reset_routes()
    # stop existing server
    deactivate_server()


def activate_server():
    """Activate routes server for this host instance."""
    routes_server = envvars.get_pyrevit_env_var(envvars.ROUTES_SERVER)
    if not routes_server:
        try:
            rsinfo = serverinfo.register()
            routes_server = \
                server.RoutesServer(
                    host=rsinfo.server_host,
                    port=rsinfo.server_port
                    )
            routes_server.start()
            envvars.set_pyrevit_env_var(envvars.ROUTES_SERVER, routes_server)
            return routes_server
        except Exception as rs_ex:
            serverinfo.unregister()
            mlogger.error("Error starting Routes server | %s", str(rs_ex))


def deactivate_server():
    """Deactivate the active routes server for this host instance."""
    routes_server = envvars.get_pyrevit_env_var(envvars.ROUTES_SERVER)
    if routes_server:
        try:
            routes_server.stop()
            envvars.set_pyrevit_env_var(envvars.ROUTES_SERVER, None)
            serverinfo.unregister()
        except Exception as rs_ex:
            mlogger.error("Error stopping Routes server | %s", str(rs_ex))


def get_active_server():
    """Get active routes server for this host instance."""
    return envvars.get_pyrevit_env_var(envvars.ROUTES_SERVER)


def make_response(data, status=OK, headers=None):
    """Create Reponse object with."""
    res = Response(status=status, data=data)
    for key, value in (headers or {}).items():
        res.add_header(key, value)
    return res


def get_routes(api_name):
    """Get all registered routes for given API name.

    Args:
        api_name (str): unique name of the api
    """
    return router.get_routes(api_name)


def add_route(api_name, pattern, method, handler_func):
    """Add new route for given API name.

    Args:
        api_name (str): unique name of the api
        pattern (str): route pattern
        method (str): method name
        handler_func (function): route handler function
    """
    return router.add_route(api_name, pattern, method, handler_func)


def remove_route(api_name, pattern, method):
    """Remove previously registered route for given API name.

    Args:
        api_name (str): unique name of the api
        pattern (str): route pattern
        method (str): method name
    """
    return router.remove_route(api_name, pattern, method)



class ColumnHeaderConverter(ExpandableObjectConverter):
 """
 Provides a type converter to convert System.Windows.Forms.ColumnHeader objects from one type to another.

 

 ColumnHeaderConverter()
 """
 def CanConvertTo(self,*__args):
  """
  CanConvertTo(self: ColumnHeaderConverter,context: ITypeDescriptorContext,destinationType: Type) -> bool

  

   Returns a value indicating whether the System.Windows.Forms.ColumnHeaderConverter can convert a 

    System.Windows.Forms.ColumnHeader to the specified type,using the specified context.

  

  

   context: A System.ComponentModel.ITypeDescriptorContext that provides a format context.

   destinationType: A type representing the type to convert to.

   Returns: true if this converter can perform the conversion; otherwise,false.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: ColumnHeaderConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   Converts the specified object to the specified type,using the specified context and culture 

    information.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   culture: A System.Globalization.CultureInfo that represents information about a culture,such as language 

    and calendar system. Can be null.

  

   value: The System.Object to convert.

   destinationType: The System.Type to convert to.

   Returns: The System.Object that is the result of the conversion.
  """
  pass



class TimeZone(object):
 """ Represents a time zone. """
 def GetDaylightChanges(self,year):
  """
  GetDaylightChanges(self: TimeZone,year: int) -> DaylightTime

  

   Returns the daylight saving time period for a particular year.

  

   year: The year that the daylight saving time period applies to.

   Returns: A System.Globalization.DaylightTime object that contains the start and end date for daylight 

    saving time in year.
  """
  pass
 def GetUtcOffset(self,time):
  """
  GetUtcOffset(self: TimeZone,time: DateTime) -> TimeSpan

  

   Returns the Coordinated Universal Time (UTC) offset for the specified local time.

  

   time: A date and time value.

   Returns: The Coordinated Universal Time (UTC) offset from Time.
  """
  pass
 def IsDaylightSavingTime(self,time,daylightTimes=None):
  """
  IsDaylightSavingTime(time: DateTime,daylightTimes: DaylightTime) -> bool

  

   Returns a value indicating whether the specified date and time is within the specified daylight 

    saving time period.

  

  

   time: A date and time.

   daylightTimes: A daylight saving time period.

   Returns: true if time is in daylightTimes; otherwise,false.

  IsDaylightSavingTime(self: TimeZone,time: DateTime) -> bool

  

   Returns a value indicating whether the specified date and time is within a daylight saving time 

    period.

  

  

   time: A date and time.

   Returns: true if time is in a daylight saving time period; otherwise,false.
  """
  pass
 def ToLocalTime(self,time):
  """
  ToLocalTime(self: TimeZone,time: DateTime) -> DateTime

  

   Returns the local time that corresponds to a specified date and time value.

  

   time: A Coordinated Universal Time (UTC) time.

   Returns: A System.DateTime object whose value is the local time that corresponds to time.
  """
  pass
 def ToUniversalTime(self,time):
  """
  ToUniversalTime(self: TimeZone,time: DateTime) -> DateTime

  

   Returns the Coordinated Universal Time (UTC) that corresponds to a specified time.

  

   time: A date and time.

   Returns: A System.DateTime object whose value is the Coordinated Universal Time (UTC) that corresponds to 

    time.
  """
  pass
 DaylightName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the daylight saving time zone name.



Get: DaylightName(self: TimeZone) -> str



"""

 StandardName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the standard time zone name.



Get: StandardName(self: TimeZone) -> str



"""


 CurrentTimeZone=None




class RowStyle(TableLayoutStyle):
 """
 Represents the look and feel of a row in a table layout.

 

 RowStyle(sizeType: SizeType,height: Single)

 RowStyle()

 RowStyle(sizeType: SizeType)
 """
 @staticmethod
 def __new__(self,sizeType=None,height=None):
  """
  __new__(cls: type)

  __new__(cls: type,sizeType: SizeType)

  __new__(cls: type,sizeType: SizeType,height: Single)
  """
  pass
 Height=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the height of a row.



Get: Height(self: RowStyle) -> Single



Set: Height(self: RowStyle)=value

"""





class TextRenderer(object):
 """ Provides methods used to measure and render text. This class cannot be inherited. """
 @staticmethod
 def DrawText(dc,text,font,*__args):
  """
  DrawText(dc: IDeviceContext,text: str,font: Font,bounds: Rectangle,foreColor: Color,backColor: Color)

   Draws the specified text within the specified bounds using the specified device context,font,

    color,and back color.

  

  

   dc: The device context in which to draw the text.

   text: The text to draw.

   font: The System.Drawing.Font to apply to the drawn text.

   bounds: The System.Drawing.Rectangle that represents the bounds of the text.

   foreColor: The System.Drawing.Color to apply to the drawn text.

   backColor: The System.Drawing.Color to apply to the area represented by bounds.

  DrawText(dc: IDeviceContext,text: str,font: Font,bounds: Rectangle,foreColor: Color)

   Draws the specified text within the specified bounds,using the specified device context,font,

    and color.

  

  

   dc: The device context in which to draw the text.

   text: The text to draw.

   font: The System.Drawing.Font to apply to the drawn text.

   bounds: The System.Drawing.Rectangle that represents the bounds of the text.

   foreColor: The System.Drawing.Color to apply to the drawn text.

  DrawText(dc: IDeviceContext,text: str,font: Font,bounds: Rectangle,foreColor: Color,backColor: Color,flags: TextFormatFlags)

   Draws the specified text within the specified bounds using the specified device context,font,

    color,back color,and formatting instructions.

  

  

   dc: The device context in which to draw the text.

   text: The text to draw.

   font: The System.Drawing.Font to apply to the drawn text.

   bounds: The System.Drawing.Rectangle that represents the bounds of the text.

   foreColor: The System.Drawing.Color to apply to the text.

   backColor: The System.Drawing.Color to apply to the area represented by bounds.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

  DrawText(dc: IDeviceContext,text: str,font: Font,bounds: Rectangle,foreColor: Color,flags: TextFormatFlags)

   Draws the specified text within the specified bounds using the specified device context,font,

    color,and formatting instructions.

  

  

   dc: The device context in which to draw the text.

   text: The text to draw.

   font: The System.Drawing.Font to apply to the drawn text.

   bounds: The System.Drawing.Rectangle that represents the bounds of the text.

   foreColor: The System.Drawing.Color to apply to the drawn text.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

  DrawText(dc: IDeviceContext,text: str,font: Font,pt: Point,foreColor: Color,backColor: Color)

   Draws the specified text at the specified location,using the specified device context,font,

    color,and back color.

  

  

   dc: The device context in which to draw the text.

   text: The text to draw.

   font: The System.Drawing.Font to apply to the drawn text.

   pt: The System.Drawing.Point that represents the upper-left corner of the drawn text.

   foreColor: The System.Drawing.Color to apply to the drawn text.

   backColor: The System.Drawing.Color to apply to the background area of the drawn text.

  DrawText(dc: IDeviceContext,text: str,font: Font,pt: Point,foreColor: Color)

   Draws the specified text at the specified location using the specified device context,font,and 

    color.

  

  

   dc: The device context in which to draw the text.

   text: The text to draw.

   font: The System.Drawing.Font to apply to the drawn text.

   pt: The System.Drawing.Point that represents the upper-left corner of the drawn text.

   foreColor: The System.Drawing.Color to apply to the drawn text.

  DrawText(dc: IDeviceContext,text: str,font: Font,pt: Point,foreColor: Color,backColor: Color,flags: TextFormatFlags)

   Draws the specified text at the specified location using the specified device context,font,

    color,back color,and formatting instructions

  

  

   dc: The device context in which to draw the text.

   text: The text to draw.

   font: The System.Drawing.Font to apply to the drawn text.

   pt: The System.Drawing.Point that represents the upper-left corner of the drawn text.

   foreColor: The System.Drawing.Color to apply to the text.

   backColor: The System.Drawing.Color to apply to the background area of the drawn text.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

  DrawText(dc: IDeviceContext,text: str,font: Font,pt: Point,foreColor: Color,flags: TextFormatFlags)

   Draws the specified text at the specified location using the specified device context,font,

    color,and formatting instructions.

  

  

   dc: The device context in which to draw the text.

   text: The text to draw.

   font: The System.Drawing.Font to apply to the drawn text.

   pt: The System.Drawing.Point that represents the upper-left corner of the drawn text.

   foreColor: The System.Drawing.Color to apply to the drawn text.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.
  """
  pass
 @staticmethod
 def MeasureText(*__args):
  """
  MeasureText(dc: IDeviceContext,text: str,font: Font) -> Size

  

   Provides the size,in pixels,of the specified text drawn with the specified font in the 

    specified device context.

  

  

   dc: The device context in which to measure the text.

   text: The text to measure.

   font: The System.Drawing.Font to apply to the measured text.

   Returns: The System.Drawing.Size,in pixels,of text drawn in a single line with the specified font in 

    the specified device context.

  

  MeasureText(dc: IDeviceContext,text: str,font: Font,proposedSize: Size) -> Size

  

   Provides the size,in pixels,of the specified text when drawn with the specified font in the 

    specified device context,using the specified size to create an initial bounding rectangle for 

    the text.

  

  

   dc: The device context in which to measure the text.

   text: The text to measure.

   font: The System.Drawing.Font to apply to the measured text.

   proposedSize: The System.Drawing.Size of the initial bounding rectangle.

   Returns: The System.Drawing.Size,in pixels,of text drawn with the specified font.

  MeasureText(dc: IDeviceContext,text: str,font: Font,proposedSize: Size,flags: TextFormatFlags) -> Size

  

   Provides the size,in pixels,of the specified text when drawn with the specified device 

    context,font,and formatting instructions,using the specified size to create the initial 

    bounding rectangle for the text.

  

  

   dc: The device context in which to measure the text.

   text: The text to measure.

   font: The System.Drawing.Font to apply to the measured text.

   proposedSize: The System.Drawing.Size of the initial bounding rectangle.

   flags: The formatting instructions to apply to the measured text.

   Returns: The System.Drawing.Size,in pixels,of text drawn with the specified font and format.

  MeasureText(text: str,font: Font) -> Size

  

   Provides the size,in pixels,of the specified text when drawn with the specified font.

  

   text: The text to measure.

   font: The System.Drawing.Font to apply to the measured text.

   Returns: The System.Drawing.Size,in pixels,of text drawn on a single line with the specified font. You 

    can manipulate how the text is drawn by using one of the 

    System.Windows.Forms.TextRenderer.DrawText(System.Drawing.IDeviceContext,System.String,System.Dra

    wing.Font,System.Drawing.Rectangle,System.Drawing.Color,System.Windows.Forms.TextFormatFlags) 

    overloads that takes a System.Windows.Forms.TextFormatFlags parameter. For example,the default 

    behavior of the System.Windows.Forms.TextRenderer is to add padding to the bounding rectangle of 

    the drawn text to accommodate overhanging glyphs. If you need to draw a line of text without 

    these extra spaces you should use the versions of 

    System.Windows.Forms.TextRenderer.DrawText(System.Drawing.IDeviceContext,System.String,System.Dra

    wing.Font,System.Drawing.Point,System.Drawing.Color) and 

    System.Windows.Forms.TextRenderer.MeasureText(System.Drawing.IDeviceContext,System.String,System.

    Drawing.Font) that take a System.Drawing.Size and System.Windows.Forms.TextFormatFlags 

    parameter. For an example,see 

    System.Windows.Forms.TextRenderer.MeasureText(System.Drawing.IDeviceContext,System.String,System.

    Drawing.Font,System.Drawing.Size,System.Windows.Forms.TextFormatFlags).

  

  MeasureText(text: str,font: Font,proposedSize: Size,flags: TextFormatFlags) -> Size

  

   Provides the size,in pixels,of the specified text when drawn with the specified font and 

    formatting instructions,using the specified size to create the initial bounding rectangle for 

    the text.

  

  

   text: The text to measure.

   font: The System.Drawing.Font to apply to the measured text.

   proposedSize: The System.Drawing.Size of the initial bounding rectangle.

   flags: The formatting instructions to apply to the measured text.

   Returns: The System.Drawing.Size,in pixels,of text drawn with the specified font and format.

  MeasureText(text: str,font: Font,proposedSize: Size) -> Size

  

   Provides the size,in pixels,of the specified text when drawn with the specified font,using 

    the specified size to create an initial bounding rectangle.

  

  

   text: The text to measure.

   font: The System.Drawing.Font to apply to the measured text.

   proposedSize: The System.Drawing.Size of the initial bounding rectangle.

   Returns: The System.Drawing.Size,in pixels,of text drawn with the specified font.
  """
  pass



class TypeDescriptionProvider(object):
 """ Provides supplemental metadata to the System.ComponentModel.TypeDescriptor. """
 def CreateInstance(self,provider,objectType,argTypes,args):
  """
  CreateInstance(self: TypeDescriptionProvider,provider: IServiceProvider,objectType: Type,argTypes: Array[Type],args: Array[object]) -> object

  

   Creates an object that can substitute for another data type.

  

   provider: An optional service provider.

   objectType: The type of object to create. This parameter is never null.

   argTypes: An optional array of types that represent the parameter types to be passed to the object's 

    constructor. This array can be null or of zero length.

  

   args: An optional array of parameter values to pass to the object's constructor.

   Returns: The substitute System.Object.
  """
  pass
 def GetCache(self,instance):
  """
  GetCache(self: TypeDescriptionProvider,instance: object) -> IDictionary

  

   Gets a per-object cache,accessed as an System.Collections.IDictionary of key/value pairs.

  

   instance: The object for which to get the cache.

   Returns: An System.Collections.IDictionary if the provided object supports caching; otherwise,null.
  """
  pass
 def GetExtendedTypeDescriptor(self,instance):
  """
  GetExtendedTypeDescriptor(self: TypeDescriptionProvider,instance: object) -> ICustomTypeDescriptor

  

   Gets an extended custom type descriptor for the given object.

  

   instance: The object for which to get the extended type descriptor.

   Returns: An System.ComponentModel.ICustomTypeDescriptor that can provide extended metadata for the object.
  """
  pass
 def GetExtenderProviders(self,*args):
  """
  GetExtenderProviders(self: TypeDescriptionProvider,instance: object) -> Array[IExtenderProvider]

  

   Gets the extender providers for the specified object.

  

   instance: The object to get extender providers for.

   Returns: An array of extender providers for instance.
  """
  pass
 def GetFullComponentName(self,component):
  """
  GetFullComponentName(self: TypeDescriptionProvider,component: object) -> str

  

   Gets the name of the specified component,or null if the component has no name.

  

   component: The specified component.

   Returns: The name of the specified component.
  """
  pass
 def GetReflectionType(self,*__args):
  """
  GetReflectionType(self: TypeDescriptionProvider,objectType: Type,instance: object) -> Type

  

   Performs normal reflection against the given object with the given type.

  

   objectType: The type of object for which to retrieve the System.Reflection.IReflect.

   instance: An instance of the type. Can be null.

   Returns: A System.Type.

  GetReflectionType(self: TypeDescriptionProvider,instance: object) -> Type

  

   Performs normal reflection against the given object.

  

   instance: An instance of the type (should not be null).

   Returns: A System.Type.

  GetReflectionType(self: TypeDescriptionProvider,objectType: Type) -> Type

  

   Performs normal reflection against a type.

  

   objectType: The type of object for which to retrieve the System.Reflection.IReflect.

   Returns: A System.Type.
  """
  pass
 def GetRuntimeType(self,reflectionType):
  """
  GetRuntimeType(self: TypeDescriptionProvider,reflectionType: Type) -> Type

  

   Converts a reflection type into a runtime type.

  

   reflectionType: The type to convert to its runtime equivalent.

   Returns: A System.Type that represents the runtime equivalent of reflectionType.
  """
  pass
 def GetTypeDescriptor(self,*__args):
  """
  GetTypeDescriptor(self: TypeDescriptionProvider,objectType: Type,instance: object) -> ICustomTypeDescriptor

  

   Gets a custom type descriptor for the given type and object.

  

   objectType: The type of object for which to retrieve the type descriptor.

   instance: An instance of the type. Can be null if no instance was passed to the 

    System.ComponentModel.TypeDescriptor.

  

   Returns: An System.ComponentModel.ICustomTypeDescriptor that can provide metadata for the type.

  GetTypeDescriptor(self: TypeDescriptionProvider,instance: object) -> ICustomTypeDescriptor

  

   Gets a custom type descriptor for the given object.

  

   instance: An instance of the type. Can be null if no instance was passed to the 

    System.ComponentModel.TypeDescriptor.

  

   Returns: An System.ComponentModel.ICustomTypeDescriptor that can provide metadata for the type.

  GetTypeDescriptor(self: TypeDescriptionProvider,objectType: Type) -> ICustomTypeDescriptor

  

   Gets a custom type descriptor for the given type.

  

   objectType: The type of object for which to retrieve the type descriptor.

   Returns: An System.ComponentModel.ICustomTypeDescriptor that can provide metadata for the type.
  """
  pass
 def IsSupportedType(self,type):
  """
  IsSupportedType(self: TypeDescriptionProvider,type: Type) -> bool

  

   Gets a value that indicates whether the specified type is compatible with the type description 

    and its chain of type description providers.

  

  

   type: The type to test for compatibility.

   Returns: true if type is compatible with the type description and its chain of type description 

    providers; otherwise,false.
  """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """
  __new__(cls: type)

  __new__(cls: type,parent: TypeDescriptionProvider)
  """
  pass



class CredentialCache(object,ICredentials,ICredentialsByHost,IEnumerable):
 """
 Provides storage for multiple credentials.

 

 CredentialCache()
 """
 def Add(self,*__args):
  """
  Add(self: CredentialCache,host: str,port: int,authenticationType: str,credential: NetworkCredential)

   Adds a System.Net.NetworkCredential instance for use with SMTP to the credential cache and 

    associates it with a host computer,port,and authentication protocol. Credentials added using 

    this method are valid for SMTP only. This method does not work for HTTP or FTP requests.

  

  

   host: A System.String that identifies the host computer.

   port: A System.Int32 that specifies the port to connect to on host.

   authenticationType: A System.String that identifies the authentication scheme used when connecting to host using 

    cred. See Remarks.

  

   credential: The System.Net.NetworkCredential to add to the credential cache.

  Add(self: CredentialCache,uriPrefix: Uri,authType: str,cred: NetworkCredential)

   Adds a System.Net.NetworkCredential instance to the credential cache for use with protocols 

    other than SMTP and associates it with a Uniform Resource Identifier (URI) prefix and 

    authentication protocol.

  

  

   uriPrefix: A System.Uri that specifies the URI prefix of the resources that the credential grants access to.

   authType: The authentication scheme used by the resource named in uriPrefix.

   cred: The System.Net.NetworkCredential to add to the credential cache.
  """
  pass
 def GetCredential(self,*__args):
  """
  GetCredential(self: CredentialCache,host: str,port: int,authenticationType: str) -> NetworkCredential

  

   Returns the System.Net.NetworkCredential instance associated with the specified host,port,and 

    authentication protocol.

  

  

   host: A System.String that identifies the host computer.

   port: A System.Int32 that specifies the port to connect to on host.

   authenticationType: A System.String that identifies the authentication scheme used when connecting to host. See 

    Remarks.

  

   Returns: A System.Net.NetworkCredential or,if there is no matching credential in the cache,null.

  GetCredential(self: CredentialCache,uriPrefix: Uri,authType: str) -> NetworkCredential

  

   Returns the System.Net.NetworkCredential instance associated with the specified Uniform Resource 

    Identifier (URI) and authentication type.

  

  

   uriPrefix: A System.Uri that specifies the URI prefix of the resources that the credential grants access to.

   authType: The authentication scheme used by the resource named in uriPrefix.

   Returns: A System.Net.NetworkCredential or,if there is no matching credential in the cache,null.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: CredentialCache) -> IEnumerator

  

   Returns an enumerator that can iterate through the System.Net.CredentialCache instance.

   Returns: An System.Collections.IEnumerator for the System.Net.CredentialCache.
  """
  pass
 def Remove(self,*__args):
  """
  Remove(self: CredentialCache,host: str,port: int,authenticationType: str)

   Deletes a System.Net.NetworkCredential instance from the cache if it is associated with the 

    specified host,port,and authentication protocol.

  

  

   host: A System.String that identifies the host computer.

   port: A System.Int32 that specifies the port to connect to on host.

   authenticationType: A System.String that identifies the authentication scheme used when connecting to host. See 

    Remarks.

  

  Remove(self: CredentialCache,uriPrefix: Uri,authType: str)

   Deletes a System.Net.NetworkCredential instance from the cache if it is associated with the 

    specified Uniform Resource Identifier (URI) prefix and authentication protocol.

  

  

   uriPrefix: A System.Uri that specifies the URI prefix of the resources that the credential is used for.

   authType: The authentication scheme used by the host named in uriPrefix.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+yx.__add__(y) <==> x+y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 DefaultCredentials=None
 DefaultNetworkCredentials=None




class GridTableStylesCollection(BaseCollection,ICollection,IEnumerable,IList):
 """ Represents a collection of System.Windows.Forms.DataGridTableStyle objects in the System.Windows.Forms.DataGrid control. """
 def Add(self,table):
  """
  Add(self: GridTableStylesCollection,table: DataGridTableStyle) -> int

  

   Adds a System.Windows.Forms.DataGridTableStyle to this collection.

  

   table: The System.Windows.Forms.DataGridTableStyle to add to the collection.

   Returns: The index of the newly added object.
  """
  pass
 def AddRange(self,tables):
  """
  AddRange(self: GridTableStylesCollection,tables: Array[DataGridTableStyle])

   Adds an array of table styles to the collection.

  

   tables: An array of System.Windows.Forms.DataGridTableStyle objects.
  """
  pass
 def Clear(self):
  """
  Clear(self: GridTableStylesCollection)

   Clears the collection.
  """
  pass
 def Contains(self,*__args):
  """
  Contains(self: GridTableStylesCollection,name: str) -> bool

  

   Gets a value indicating whether the System.Windows.Forms.GridTableStylesCollection contains the 

    System.Windows.Forms.DataGridTableStyle specified by name.

  

  

   name: The System.Windows.Forms.DataGridTableStyle.MappingName of the 

    System.Windows.Forms.DataGridTableStyle to look for.

  

   Returns: true if the specified table style exists in the collection; otherwise,false.

  Contains(self: GridTableStylesCollection,table: DataGridTableStyle) -> bool

  

   Gets a value indicating whether the System.Windows.Forms.GridTableStylesCollection contains the 

    specified System.Windows.Forms.DataGridTableStyle.

  

  

   table: The System.Windows.Forms.DataGridTableStyle to look for.

   Returns: true if the specified table style exists in the collection; otherwise,false.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def OnCollectionChanged(self,*args):
  """
  OnCollectionChanged(self: GridTableStylesCollection,e: CollectionChangeEventArgs)

   Raises the System.Windows.Forms.GridTableStylesCollection.CollectionChanged event.

  

   e: A System.ComponentModel.CollectionChangeEventArgs containing the event data.
  """
  pass
 def Remove(self,table):
  """
  Remove(self: GridTableStylesCollection,table: DataGridTableStyle)

   Removes the specified System.Windows.Forms.DataGridTableStyle.

  

   table: The System.Windows.Forms.DataGridTableStyle to remove.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: GridTableStylesCollection,index: int)

   Removes a System.Windows.Forms.DataGridTableStyle at the specified index.

  

   index: The index of the System.Windows.Forms.DataGridTableStyle to remove.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IList,value: object) -> bool

  

   Determines whether the System.Collections.IList contains a specific value.

  

   value: The object to locate in the System.Collections.IList.

   Returns: true if the System.Object is found in the System.Collections.IList; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 List=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the underlying list.



"""


 CollectionChanged=None




import rpw
from rpw import revit, DB
from rpw.base import BaseObjectWrapper


class BoundingBox(BaseObjectWrapper):

#     """ BoundingBoxElement receives a Revit Object for access to properties.
#     Usage:
#     bbox = BoundingBoxElement(element)
#     bbox.element: element
#     Properties:
#     bbox.min: min coordinate of bounding box
#     bbox.max: min coordinate of bounding box
#     bbox.average: min coordinate of bounding box
#     """
#
    def __init__(self, element):
        raise NotImplemented
#         self.element = element
#         self.bbox = element.get_BoundingBox(revit.doc.ActiveView)
#
#     @property
#     def min(self):
#         x, y, z = self.bbox.Min.X, self.bbox.Min.Y, self.bbox.Min.Z
#         return PointElement(x, y, z)
#
#     @property
#     def max(self):
#         x, y, z = self.bbox.Max.X, self.bbox.Max.Y, self.bbox.Max.Z
#         return PointElement(x, y, z)
#
#     @property
#     def average(self):
#         return PointCollection(self.min, self.max).average
#
#     def __repr__(self):
#         return '<BB: MIN{} MAX={} CENTER={}>'.format(self.min, self.max,
#                                                      self.center)
#
#     def __str__(self):
#         return repr(self)
#
# class Curve():
#     pass



class RepeatBehaviorConverter(TypeConverter):
 """
 Converts instances of System.Windows.Media.Animation.RepeatBehavior to and from other data types.

 

 RepeatBehaviorConverter()
 """
 def CanConvertFrom(self,*__args):
  """
  CanConvertFrom(self: RepeatBehaviorConverter,td: ITypeDescriptorContext,t: Type) -> bool

  

   Determines whether or not conversion from a specified data type is possible.

  

   td: Context information required for conversion.

   t: Type to evaluate for conversion.

   Returns: true if conversion is supported; otherwise,false.
  """
  pass
 def CanConvertTo(self,*__args):
  """
  CanConvertTo(self: RepeatBehaviorConverter,context: ITypeDescriptorContext,destinationType: Type) -> bool

  

   Determines if conversion to a specified type is possible.

  

   context: Context information required for conversion.

   destinationType: Destination type being evaluated for conversion.

   Returns: true if conversion is possible; otherwise,false.
  """
  pass
 def ConvertFrom(self,*__args):
  """
  ConvertFrom(self: RepeatBehaviorConverter,td: ITypeDescriptorContext,cultureInfo: CultureInfo,value: object) -> object

  

   Converts a given string value to an instance of 

    System.Windows.Media.Animation.RepeatBehaviorConverter.

  

  

   td: Context information required for conversion.

   cultureInfo: Cultural information to respect during conversion.

   value: Object being evaluated for conversion.

   Returns: A new System.Windows.Media.Animation.RepeatBehavior object based on value.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: RepeatBehaviorConverter,context: ITypeDescriptorContext,cultureInfo: CultureInfo,value: object,destinationType: Type) -> object

  

   Converts an instance of System.Windows.Media.Animation.RepeatBehavior to a supported destination 

    type.

  

  

   context: Context information required for conversion.

   cultureInfo: Cultural information to respect during conversion.

   value: Object being evaluated for conversion.

   destinationType: Destination type being evaluated for conversion.

   Returns: The only supported destination types are System.String and 

    System.ComponentModel.Design.Serialization.InstanceDescriptor.
  """
  pass



class ComboBoxRenderer(object):
 """ Provides methods used to render a combo box control with visual styles. This class cannot be inherited. """
 @staticmethod
 def DrawDropDownButton(g,bounds,state):
  """
  DrawDropDownButton(g: Graphics,bounds: Rectangle,state: ComboBoxState)

   Draws a drop-down arrow with the current visual style of the operating system.

  

   g: The System.Drawing.Graphics used to draw the drop-down arrow.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the drop-down arrow.

   state: One of the System.Windows.Forms.VisualStyles.ComboBoxState values that specifies the visual 

    state of the drop-down arrow.
  """
  pass
 @staticmethod
 def DrawTextBox(g,bounds,*__args):
  """
  DrawTextBox(g: Graphics,bounds: Rectangle,comboBoxText: str,font: Font,flags: TextFormatFlags,state: ComboBoxState)

   Draws a text box in the specified state and bounds,with the specified text and text formatting.

  

   g: The System.Drawing.Graphics used to draw the text box.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the text box.

   comboBoxText: The System.String to draw in the text box.

   font: The System.Drawing.Font to apply to comboBoxText.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

   state: One of the System.Windows.Forms.VisualStyles.ComboBoxState values that specifies the visual 

    state of the text box.

  

  DrawTextBox(g: Graphics,bounds: Rectangle,comboBoxText: str,font: Font,textBounds: Rectangle,flags: TextFormatFlags,state: ComboBoxState)

   Draws a text box in the specified state and bounds,with the specified text,text formatting,

    and text bounds.

  

  

   g: The System.Drawing.Graphics used to draw the text box.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the text box.

   comboBoxText: The System.String to draw in the text box.

   font: The System.Drawing.Font to apply to comboBoxText.

   textBounds: The System.Drawing.Rectangle that specifies the bounds in which to draw comboBoxText.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

   state: One of the System.Windows.Forms.VisualStyles.ComboBoxState values that specifies the visual 

    state of the text box.

  

  DrawTextBox(g: Graphics,bounds: Rectangle,comboBoxText: str,font: Font,textBounds: Rectangle,state: ComboBoxState)

   Draws a text box in the specified state and bounds,with the specified text and text bounds.

  

   g: The System.Drawing.Graphics used to draw the text box.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the text box.

   comboBoxText: The System.String to draw in the text box.

   font: The System.Drawing.Font to apply to comboBoxText.

   textBounds: The System.Drawing.Rectangle that specifies the bounds in which to draw comboBoxText.

   state: One of the System.Windows.Forms.VisualStyles.ComboBoxState values that specifies the visual 

    state of the text box.

  

  DrawTextBox(g: Graphics,bounds: Rectangle,state: ComboBoxState)

   Draws a text box in the specified state and bounds.

  

   g: The System.Drawing.Graphics used to draw the text box.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the text box.

   state: One of the System.Windows.Forms.VisualStyles.ComboBoxState values that specifies the visual 

    state of the text box.

  

  DrawTextBox(g: Graphics,bounds: Rectangle,comboBoxText: str,font: Font,state: ComboBoxState)

   Draws a text box in the specified state and bounds,with the specified text.

  

   g: The System.Drawing.Graphics used to draw the text box.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the text box.

   comboBoxText: The System.String to draw in the text box.

   font: The System.Drawing.Font to apply to comboBoxText.

   state: One of the System.Windows.Forms.VisualStyles.ComboBoxState values that specifies the visual 

    state of the text box.
  """
  pass
 IsSupported=True




class MarshalByRefObject(object):
 """ Enables access to objects across application domain boundaries in applications that support remoting. """
 def CreateObjRef(self,requestedType):
  """
  CreateObjRef(self: MarshalByRefObject,requestedType: Type) -> ObjRef

  

   Creates an object that contains all the relevant information required to generate a proxy used 

    to communicate with a remote object.

  

  

   requestedType: The System.Type of the object that the new System.Runtime.Remoting.ObjRef will reference.

   Returns: Information required to generate a proxy.
  """
  pass
 def GetLifetimeService(self):
  """
  GetLifetimeService(self: MarshalByRefObject) -> object

  

   Retrieves the current lifetime service object that controls the lifetime policy for this 

    instance.

  

   Returns: An object of type System.Runtime.Remoting.Lifetime.ILease used to control the lifetime policy 

    for this instance.
  """
  pass
 def InitializeLifetimeService(self):
  """
  InitializeLifetimeService(self: MarshalByRefObject) -> object

  

   Obtains a lifetime service object to control the lifetime policy for this instance.

   Returns: An object of type System.Runtime.Remoting.Lifetime.ILease used to control the lifetime policy 

    for this instance. This is the current lifetime service object for this instance if one exists; 

    otherwise,a new lifetime service object initialized to the value of the 

    System.Runtime.Remoting.Lifetime.LifetimeServices.LeaseManagerPollTime property.
  """
  pass



class RegistrationServices(object,IRegistrationServices):
 """
 Provides a set of services for registering and unregistering managed assemblies for use from COM.

 

 RegistrationServices()
 """
 def GetManagedCategoryGuid(self):
  """
  GetManagedCategoryGuid(self: RegistrationServices) -> Guid

  

   Returns the GUID of the COM category that contains the managed classes.

   Returns: The GUID of the COM category that contains the managed classes.
  """
  pass
 def GetProgIdForType(self,type):
  """
  GetProgIdForType(self: RegistrationServices,type: Type) -> str

  

   Retrieves the COM ProgID for the specified type.

  

   type: The type corresponding to the ProgID that is being requested.

   Returns: The ProgID for the specified type.
  """
  pass
 def GetRegistrableTypesInAssembly(self,assembly):
  """
  GetRegistrableTypesInAssembly(self: RegistrationServices,assembly: Assembly) -> Array[Type]

  

   Retrieves a list of classes in an assembly that would be registered by a call to 

    System.Runtime.InteropServices.RegistrationServices.RegisterAssembly(System.Reflection.Assembly,S

    ystem.Runtime.InteropServices.AssemblyRegistrationFlags).

  

  

   assembly: The assembly to search for classes.

   Returns: A System.Type array containing a list of classes in assembly.
  """
  pass
 def RegisterAssembly(self,assembly,flags):
  """
  RegisterAssembly(self: RegistrationServices,assembly: Assembly,flags: AssemblyRegistrationFlags) -> bool

  

   Registers the classes in a managed assembly to enable creation from COM.

  

   assembly: The assembly to be registered.

   flags: An System.Runtime.InteropServices.AssemblyRegistrationFlags value indicating any special 

    settings used when registering assembly.

  

   Returns: true if assembly contains types that were successfully registered; otherwise false if the 

    assembly contains no eligible types.
  """
  pass
 def RegisterTypeForComClients(self,type,*__args):
  """
  RegisterTypeForComClients(self: RegistrationServices,type: Type,classContext: RegistrationClassContext,flags: RegistrationConnectionType) -> int

  

   Registers the specified type with COM using the specified execution context and connection type.

  

   type: The System.Type object to register for use from COM.

   classContext: One of the System.Runtime.InteropServices.RegistrationClassContext values that indicates the 

    context in which the executable code will be run.

  

   flags: One of the System.Runtime.InteropServices.RegistrationConnectionType values that specifies how 

    connections are made to the class object.

  

   Returns: An integer that represents a cookie value.

  RegisterTypeForComClients(self: RegistrationServices,type: Type,g: Guid) -> Guid

  

   Registers the specified type with COM using the specified GUID.

  

   type: The System.Type to be registered for use from COM.

   g: The System.Guid used to register the specified type.
  """
  pass
 def TypeRepresentsComType(self,type):
  """
  TypeRepresentsComType(self: RegistrationServices,type: Type) -> bool

  

   Indicates whether a type is marked with the System.Runtime.InteropServices.ComImportAttribute,

    or derives from a type marked with the System.Runtime.InteropServices.ComImportAttribute and 

    shares the same GUID as the parent.

  

  

   type: The type to check for being a COM type.

   Returns: true if a type is marked with the System.Runtime.InteropServices.ComImportAttribute,or derives 

    from a type marked with the System.Runtime.InteropServices.ComImportAttribute and shares the 

    same GUID as the parent; otherwise false.
  """
  pass
 def TypeRequiresRegistration(self,type):
  """
  TypeRequiresRegistration(self: RegistrationServices,type: Type) -> bool

  

   Determines whether the specified type requires registration.

  

   type: The type to check for COM registration requirements.

   Returns: true if the type must be registered for use from COM; otherwise false.
  """
  pass
 def UnregisterAssembly(self,assembly):
  """
  UnregisterAssembly(self: RegistrationServices,assembly: Assembly) -> bool

  

   Unregisters the classes in a managed assembly.

  

   assembly: The assembly to be unregistered.

   Returns: true if assembly contains types that were successfully unregistered; otherwise false if the 

    assembly contains no eligible types.
  """
  pass
 def UnregisterTypeForComClients(self,cookie):
  """
  UnregisterTypeForComClients(self: RegistrationServices,cookie: int)

   Removes references to a type registered with the 

    System.Runtime.InteropServices.RegistrationServices.RegisterTypeForComClients(System.Type,System.

    Runtime.InteropServices.RegistrationClassContext,System.Runtime.InteropServices.RegistrationConne

    ctionType) method.

  

  

   cookie: The cookie value returned by a previous call to the 

    System.Runtime.InteropServices.RegistrationServices.RegisterTypeForComClients(System.Type,System.

    Runtime.InteropServices.RegistrationClassContext,System.Runtime.InteropServices.RegistrationConne

    ctionType) method overload.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass



"""
Category Wrapper

"""  #

import rpw
from rpw import revit, DB
from rpw.db.element import Element
from rpw.base import BaseObjectWrapper
from rpw.utils.logger import logger, deprecate_warning
from rpw.db.builtins import BicEnum


class Category(BaseObjectWrapper):
    """
    `DB.Category` Wrapper

    Attribute:
        _revit_object (DB.Family): Wrapped ``DB.Category``
    """

    _revit_object_class = DB.Category

    @property
    def name(self):
        """ Returns name of the Category """
        return self._revit_object.Name

    def get_families(self, wrapped=True, doc=None):
        """
        Returns:
            Families (``DB.Family``): List of Family elements in this
            same category

        """
        # There has to be a better way, but perhaps not: https://goo.gl/MqdzWg
        unique_family_ids = set()
        for symbol in self.get_symbols(wrapped=True):
            unique_family_ids.add(symbol.family.Id)
        doc = doc or revit.doc
        elements = [doc.GetElement(family_id) for family_id in unique_family_ids]
        return [Element(e) for e in elements] if wrapped else elements

    @property
    def families(self):
        deprecate_warning('Category.families',
                          'Category.get_families(wrapped=True')
        return self.get_families(wrapped=True)

    def get_symbols(self, wrapped=True):
        """
        Returns:
            Symbols (``DB.FamilySymbol``): List of Symbol Types in the Category
        """
        collector = rpw.db.Collector(of_category=self.builtin, is_type=True)
        return collector.get_elements(wrapped)

    @property
    def symbols(self):
        deprecate_warning('Category.symbols',
                          'Category.get_symbols(wrapped=True')
        return self.get_symbols(wrapped=True)

    def get_instances(self, wrapped=True):
        """
        Returns:
            (``DB.FamilyInstance``): List of Symbol Instances in the Category.
        """
        collector = rpw.db.Collector(of_category=self.builtin, is_not_type=True)
        return collector.get_elements(wrapped)

    @property
    def instances(self):
        deprecate_warning('Category.instances',
                          'Category.get_instances(wrapped=True')
        return self.get_instances(wrapped=True)

    @property
    def builtin(self):
        """ Returns BuiltInCategory of the Category """
        return BicEnum.from_category_id(self._revit_object.Id)

    @property
    def _builtin_enum(self):
        deprecate_warning('Category._builtin_enum()', 'Category.builtin')
        return self.builtin

    def __repr__(self):
        return super(Category, self).__repr__({'name': self.name})



class Exception(object,ISerializable,_Exception):
 """
 Represents errors that occur during application execution.

 

 Exception()

 Exception(message: str)

 Exception(message: str,innerException: Exception)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def GetBaseException(self):
  """
  GetBaseException(self: Exception) -> Exception

  

   When overridden in a derived class,returns the System.Exception that is the root cause of one 

    or more subsequent exceptions.

  

   Returns: The first exception thrown in a chain of exceptions. If the System.Exception.InnerException 

    property of the current exception is a null reference (Nothing in Visual Basic),this property 

    returns the current exception.
  """
  pass
 def GetObjectData(self,info,context):
  """
  GetObjectData(self: Exception,info: SerializationInfo,context: StreamingContext)

   When overridden in a derived class,sets the System.Runtime.Serialization.SerializationInfo with 

    information about the exception.

  

  

   info: The System.Runtime.Serialization.SerializationInfo that holds the serialized object data about 

    the exception being thrown.

  

   context: The System.Runtime.Serialization.StreamingContext that contains contextual information about the 

    source or destination.
  """
  pass
 def GetType(self):
  """
  GetType(self: Exception) -> Type

  

   Gets the runtime type of the current instance.

   Returns: A System.Type object that represents the exact runtime type of the current instance.
  """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def ToString(self):
  """
  ToString(self: Exception) -> str

  

   Creates and returns a string representation of the current exception.

   Returns: A string representation of the current exception.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,message=None,innerException=None):
  """
  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,innerException: Exception)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __str__(self,*args):
  pass
 Data=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection of key/value pairs that provide additional user-defined information about the exception.



Get: Data(self: Exception) -> IDictionary



"""

 HelpLink=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a link to the help file associated with this exception.



Get: HelpLink(self: Exception) -> str



Set: HelpLink(self: Exception)=value

"""

 HResult=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets HRESULT,a coded numerical value that is assigned to a specific exception.



Get: HResult(self: Exception) -> int



"""

 InnerException=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Exception instance that caused the current exception.



Get: InnerException(self: Exception) -> Exception



"""

 Message=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a message that describes the current exception.



Get: Message(self: Exception) -> str



"""

 Source=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the application or the object that causes the error.



Get: Source(self: Exception) -> str



Set: Source(self: Exception)=value

"""

 StackTrace=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a string representation of the immediate frames on the call stack.



Get: StackTrace(self: Exception) -> str



"""

 TargetSite=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the method that throws the current exception.



Get: TargetSite(self: Exception) -> MethodBase



"""





class ExceptionValidationRule(ValidationRule):
 """
 Represents a rule that checks for exceptions that are thrown during the update of the binding source property.

 

 ExceptionValidationRule()
 """
 def Validate(self,value,cultureInfo,owner=None):
  """
  Validate(self: ExceptionValidationRule,value: object,cultureInfo: CultureInfo) -> ValidationResult

  

   Performs validation checks on a value.

  

   value: The value (from the binding target) to check.

   cultureInfo: The culture to use in this rule.

   Returns: A System.Windows.Controls.ValidationResult object.
  """
  pass



class ScrollChangedEventArgs(RoutedEventArgs):
 """ Describes a change in the scrolling state and contains the required arguments for a System.Windows.Controls.ScrollViewer.ScrollChanged event. """
 ExtentHeight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the updated height of the System.Windows.Controls.ScrollViewer extent.



Get: ExtentHeight(self: ScrollChangedEventArgs) -> float



"""

 ExtentHeightChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates the change in height of the System.Windows.Controls.ScrollViewer extent.



Get: ExtentHeightChange(self: ScrollChangedEventArgs) -> float



"""

 ExtentWidth=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the updated width of the System.Windows.Controls.ScrollViewer extent.



Get: ExtentWidth(self: ScrollChangedEventArgs) -> float



"""

 ExtentWidthChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates the change in width of the System.Windows.Controls.ScrollViewer extent.



Get: ExtentWidthChange(self: ScrollChangedEventArgs) -> float



"""

 HorizontalChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates the change in horizontal offset for a System.Windows.Controls.ScrollViewer.



Get: HorizontalChange(self: ScrollChangedEventArgs) -> float



"""

 HorizontalOffset=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the updated horizontal offset value for a System.Windows.Controls.ScrollViewer.



Get: HorizontalOffset(self: ScrollChangedEventArgs) -> float



"""

 VerticalChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates the change in vertical offset of a System.Windows.Controls.ScrollViewer.



Get: VerticalChange(self: ScrollChangedEventArgs) -> float



"""

 VerticalOffset=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the updated value of the vertical offset for a System.Windows.Controls.ScrollViewer.



Get: VerticalOffset(self: ScrollChangedEventArgs) -> float



"""

 ViewportHeight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the updated value of the viewport height for a System.Windows.Controls.ScrollViewer.



Get: ViewportHeight(self: ScrollChangedEventArgs) -> float



"""

 ViewportHeightChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates the change in value of the viewport height for a System.Windows.Controls.ScrollViewer.



Get: ViewportHeightChange(self: ScrollChangedEventArgs) -> float



"""

 ViewportWidth=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the updated value of the viewport width for a System.Windows.Controls.ScrollViewer.



Get: ViewportWidth(self: ScrollChangedEventArgs) -> float



"""

 ViewportWidthChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates the change in viewport width of a System.Windows.Controls.ScrollViewer.



Get: ViewportWidthChange(self: ScrollChangedEventArgs) -> float



"""





class TableLayoutRowStyleCollection(TableLayoutStyleCollection,IList,ICollection,IEnumerable):
 """ A collection that stores System.Windows.Forms.RowStyle objects. """
 def Add(self,*__args):
  """
  Add(self: TableLayoutRowStyleCollection,rowStyle: RowStyle) -> int

  

   Adds a new System.Windows.Forms.RowStyle to the 

    System.Windows.Forms.TableLayoutRowStyleCollection.

  

  

   rowStyle: The System.Windows.Forms.RowStyle to add to the 

    System.Windows.Forms.TableLayoutRowStyleCollection.

  

   Returns: The position into which the new element was inserted.
  """
  pass
 def Contains(self,rowStyle):
  """
  Contains(self: TableLayoutRowStyleCollection,rowStyle: RowStyle) -> bool

  

   Determines whether the System.Windows.Forms.TableLayoutRowStyleCollection contains a specific 

    style.

  

  

   rowStyle: The System.Windows.Forms.RowStyle to locate in the 

    System.Windows.Forms.TableLayoutRowStyleCollection.

  

   Returns: true if the System.Windows.Forms.RowStyle is found in the 

    System.Windows.Forms.TableLayoutRowStyleCollection; otherwise,false.
  """
  pass
 def IndexOf(self,rowStyle):
  """
  IndexOf(self: TableLayoutRowStyleCollection,rowStyle: RowStyle) -> int

  

   Determines the index of a specific item in the 

    System.Windows.Forms.TableLayoutRowStyleCollection.

  

  

   rowStyle: The System.Windows.Forms.RowStyle to locate in the 

    System.Windows.Forms.TableLayoutRowStyleCollection.

  

   Returns: The index of rowStyle if found in the System.Windows.Forms.TableLayoutRowStyleCollection; 

    otherwise,-1.
  """
  pass
 def Insert(self,index,rowStyle):
  """
  Insert(self: TableLayoutRowStyleCollection,index: int,rowStyle: RowStyle)

   Inserts a System.Windows.Forms.RowStyle into the 

    System.Windows.Forms.TableLayoutRowStyleCollection at the specified position.

  

  

   index: The zero-based index at which the System.Windows.Forms.RowStyle should be inserted.

   rowStyle: The System.Windows.Forms.RowStyle to insert into the 

    System.Windows.Forms.TableLayoutRowStyleCollection. The value can be null.
  """
  pass
 def Remove(self,rowStyle):
  """
  Remove(self: TableLayoutRowStyleCollection,rowStyle: RowStyle)

   Removes the first occurrence of a specific object from the 

    System.Windows.Forms.TableLayoutRowStyleCollection.

  

  

   rowStyle: The System.Windows.Forms.RowStyle to remove from the 

    System.Windows.Forms.TableLayoutRowStyleCollection. The value can be null.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass



class DataGridComboBoxColumn(DataGridColumn):
 """
 Represents a System.Windows.Controls.DataGrid column that hosts System.Windows.Controls.ComboBox controls in its cells.

 

 DataGridComboBoxColumn()
 """
 def OnSelectedItemBindingChanged(self,*args):
  """
  OnSelectedItemBindingChanged(self: DataGridComboBoxColumn,oldBinding: BindingBase,newBinding: BindingBase)

   Notifies the System.Windows.Controls.DataGrid when the 

    System.Windows.Controls.DataGridComboBoxColumn.SelectedItemBinding property changes.

  

  

   oldBinding: The previous binding.

   newBinding: The binding that the column has been changed to.
  """
  pass
 def OnSelectedValueBindingChanged(self,*args):
  """
  OnSelectedValueBindingChanged(self: DataGridComboBoxColumn,oldBinding: BindingBase,newBinding: BindingBase)

   Notifies the System.Windows.Controls.DataGrid when the 

    System.Windows.Controls.DataGridComboBoxColumn.SelectedValueBinding property changes.

  

  

   oldBinding: The previous binding.

   newBinding: The binding that the column has been changed to.
  """
  pass
 def OnTextBindingChanged(self,*args):
  """
  OnTextBindingChanged(self: DataGridComboBoxColumn,oldBinding: BindingBase,newBinding: BindingBase)

   Notifies the System.Windows.Controls.DataGrid when the 

    System.Windows.Controls.DataGridComboBoxColumn.TextBinding property changes.

  

  

   oldBinding: The previous binding.

   newBinding: The binding that the column has been changed to.
  """
  pass
 ClipboardContentBinding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the binding object to use when getting or setting cell content for the clipboard.



Get: ClipboardContentBinding(self: DataGridComboBoxColumn) -> BindingBase



Set: ClipboardContentBinding(self: DataGridComboBoxColumn)=value

"""

 DataGridOwner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Controls.DataGrid control that contains this column.



"""

 DisplayMemberPath=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a path to a value on the source object to provide the visual representation of the object.



Get: DisplayMemberPath(self: DataGridComboBoxColumn) -> str



Set: DisplayMemberPath(self: DataGridComboBoxColumn)=value

"""

 EditingElementStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the style that is used when rendering the element that the column displays for a cell in editing mode.



Get: EditingElementStyle(self: DataGridComboBoxColumn) -> Style



Set: EditingElementStyle(self: DataGridComboBoxColumn)=value

"""

 ElementStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the style that is used when rendering the element that the column displays for a cell that is not in editing mode.



Get: ElementStyle(self: DataGridComboBoxColumn) -> Style



Set: ElementStyle(self: DataGridComboBoxColumn)=value

"""

 ItemsSource=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a collection that is used to generate the content of the combo box control.



Get: ItemsSource(self: DataGridComboBoxColumn) -> IEnumerable



Set: ItemsSource(self: DataGridComboBoxColumn)=value

"""

 SelectedItemBinding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the binding for the currently selected item.



Get: SelectedItemBinding(self: DataGridComboBoxColumn) -> BindingBase



Set: SelectedItemBinding(self: DataGridComboBoxColumn)=value

"""

 SelectedValueBinding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value of the selected item,obtained by using System.Windows.Controls.DataGridComboBoxColumn.SelectedValuePath.



Get: SelectedValueBinding(self: DataGridComboBoxColumn) -> BindingBase



Set: SelectedValueBinding(self: DataGridComboBoxColumn)=value

"""

 SelectedValuePath=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the path that is used to get the System.Windows.Controls.Primitives.Selector.SelectedValue from the System.Windows.Controls.Primitives.Selector.SelectedItem.



Get: SelectedValuePath(self: DataGridComboBoxColumn) -> str



Set: SelectedValuePath(self: DataGridComboBoxColumn)=value

"""

 TextBinding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the binding for the text in the text box portion of the System.Windows.Controls.ComboBox control.



Get: TextBinding(self: DataGridComboBoxColumn) -> BindingBase



Set: TextBinding(self: DataGridComboBoxColumn)=value

"""


 DefaultEditingElementStyle=None
 DefaultElementStyle=None
 DisplayMemberPathProperty=None
 EditingElementStyleProperty=None
 ElementStyleProperty=None
 ItemsSourceProperty=None
 SelectedValuePathProperty=None
 TextBlockComboBoxStyleKey=None




class SocketAddress(object):
 """
 Stores serialized information from System.Net.EndPoint derived classes.

 

 SocketAddress(family: AddressFamily,size: int)

 SocketAddress(family: AddressFamily)
 """
 def Equals(self,comparand):
  """
  Equals(self: SocketAddress,comparand: object) -> bool

  

   Determines whether the specified System.Object is equal to the current System.Net.SocketAddress 

    instance.

  

  

   comparand: The specified System.Object to compare with the current System.Net.SocketAddress instance.

   Returns: true if the specified System.Object is equal to the current System.Object; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: SocketAddress) -> int

  

   Serves as a hash function for a particular type,suitable for use in hashing algorithms and data 

    structures like a hash table.

  

   Returns: A hash code for the current System.Object.
  """
  pass
 def ToString(self):
  """
  ToString(self: SocketAddress) -> str

  

   Returns information about the socket address.

   Returns: A string that contains information about the System.Net.SocketAddress.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 @staticmethod
 def __new__(self,family,size=None):
  """
  __new__(cls: type,family: AddressFamily)

  __new__(cls: type,family: AddressFamily,size: int)
  """
  pass
 def __ne__(self,*args):
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Family=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Net.Sockets.AddressFamily enumerated value of the current System.Net.SocketAddress.



Get: Family(self: SocketAddress) -> AddressFamily



"""

 Size=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the underlying buffer size of the System.Net.SocketAddress.



Get: Size(self: SocketAddress) -> int



"""





class ApplicationId(object):
 """
 Contains information used to uniquely identify a manifest-based application. This class cannot be inherited.

 

 ApplicationId(publicKeyToken: Array[Byte],name: str,version: Version,processorArchitecture: str,culture: str)
 """
 def Copy(self):
  """
  Copy(self: ApplicationId) -> ApplicationId

  

   Creates and returns an identical copy of the current application identity.

   Returns: An System.ApplicationId object that represents an exact copy of the original.
  """
  pass
 def Equals(self,o):
  """
  Equals(self: ApplicationId,o: object) -> bool

  

   Determines whether the specified System.ApplicationId object is equivalent to the current 

    System.ApplicationId.

  

  

   o: The System.ApplicationId object to compare to the current System.ApplicationId.

   Returns: true if the specified System.ApplicationId object is equivalent to the current 

    System.ApplicationId; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: ApplicationId) -> int

  

   Gets the hash code for the current application identity.

   Returns: The hash code for the current application identity.
  """
  pass
 def ToString(self):
  """
  ToString(self: ApplicationId) -> str

  

   Creates and returns a string representation of the application identity.

   Returns: A string representation of the application identity.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,publicKeyToken,name,version,processorArchitecture,culture):
  """ __new__(cls: type,publicKeyToken: Array[Byte],name: str,version: Version,processorArchitecture: str,culture: str) """
  pass
 def __ne__(self,*args):
  pass
 Culture=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a string representing the culture information for the application.



Get: Culture(self: ApplicationId) -> str



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the application.



Get: Name(self: ApplicationId) -> str



"""

 ProcessorArchitecture=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the target processor architecture for the application.



Get: ProcessorArchitecture(self: ApplicationId) -> str



"""

 PublicKeyToken=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the public key token for the application.



Get: PublicKeyToken(self: ApplicationId) -> Array[Byte]



"""

 Version=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the version of the application.



Get: Version(self: ApplicationId) -> Version



"""





class ArgIterator(object):
 """
 Represents a variable-length argument list; that is,the parameters of a function that takes a variable number of arguments.

 

 ArgIterator(arglist: RuntimeArgumentHandle)

 ArgIterator(arglist: RuntimeArgumentHandle,ptr: Void*)
 """
 def End(self):
  """
  End(self: ArgIterator)

   Concludes processing of the variable-length argument list represented by this instance.
  """
  pass
 def Equals(self,o):
  """
  Equals(self: ArgIterator,o: object) -> bool

  

   This method is not supported,and always throws System.NotSupportedException.

  

   o: An object to be compared to this instance.

   Returns: This comparison is not supported. No value is returned.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: ArgIterator) -> int

  

   Returns the hash code of this object.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 def GetNextArg(self,rth=None):
  """
  GetNextArg(self: ArgIterator,rth: RuntimeTypeHandle) -> TypedReference

  

   Returns the next argument in a variable-length argument list that has a specified type.

  

   rth: A runtime type handle that identifies the type of the argument to retrieve.

   Returns: The next argument as a System.TypedReference object.

  GetNextArg(self: ArgIterator) -> TypedReference

  

   Returns the next argument in a variable-length argument list.

   Returns: The next argument as a System.TypedReference object.
  """
  pass
 def GetNextArgType(self):
  """
  GetNextArgType(self: ArgIterator) -> RuntimeTypeHandle

  

   Returns the type of the next argument.

   Returns: The type of the next argument.
  """
  pass
 def GetRemainingCount(self):
  """
  GetRemainingCount(self: ArgIterator) -> int

  

   Returns the number of arguments remaining in the argument list.

   Returns: The number of remaining arguments.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,arglist,ptr=None):
  """
  __new__(cls: type,arglist: RuntimeArgumentHandle)

  __new__(cls: type,arglist: RuntimeArgumentHandle,ptr: Void*)
  """
  pass
 def __ne__(self,*args):
  pass



class IDataGridViewEditingControl:
 """ Defines common functionality for controls that are hosted within cells of a System.Windows.Forms.DataGridView. """
 def ApplyCellStyleToEditingControl(self,dataGridViewCellStyle):
  """
  ApplyCellStyleToEditingControl(self: IDataGridViewEditingControl,dataGridViewCellStyle: DataGridViewCellStyle)

   Changes the control's user interface (UI) to be consistent with the specified cell style.

  

   dataGridViewCellStyle: The System.Windows.Forms.DataGridViewCellStyle to use as the model for the UI.
  """
  pass
 def EditingControlWantsInputKey(self,keyData,dataGridViewWantsInputKey):
  """
  EditingControlWantsInputKey(self: IDataGridViewEditingControl,keyData: Keys,dataGridViewWantsInputKey: bool) -> bool

  

   Determines whether the specified key is a regular input key that the editing control should 

    process or a special key that the System.Windows.Forms.DataGridView should process.

  

  

   keyData: A System.Windows.Forms.Keys that represents the key that was pressed.

   dataGridViewWantsInputKey: true when the System.Windows.Forms.DataGridView wants to process the System.Windows.Forms.Keys 

    in keyData; otherwise,false.

  

   Returns: true if the specified key is a regular input key that should be handled by the editing control; 

    otherwise,false.
  """
  pass
 def GetEditingControlFormattedValue(self,context):
  """
  GetEditingControlFormattedValue(self: IDataGridViewEditingControl,context: DataGridViewDataErrorContexts) -> object

  

   Retrieves the formatted value of the cell.

  

   context: A bitwise combination of System.Windows.Forms.DataGridViewDataErrorContexts values that 

    specifies the context in which the data is needed.

  

   Returns: An System.Object that represents the formatted version of the cell contents.
  """
  pass
 def PrepareEditingControlForEdit(self,selectAll):
  """
  PrepareEditingControlForEdit(self: IDataGridViewEditingControl,selectAll: bool)

   Prepares the currently selected cell for editing.

  

   selectAll: true to select all of the cell's content; otherwise,false.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 EditingControlDataGridView=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Windows.Forms.DataGridView that contains the cell.



Get: EditingControlDataGridView(self: IDataGridViewEditingControl) -> DataGridView



Set: EditingControlDataGridView(self: IDataGridViewEditingControl)=value

"""

 EditingControlFormattedValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the formatted value of the cell being modified by the editor.



Get: EditingControlFormattedValue(self: IDataGridViewEditingControl) -> object



Set: EditingControlFormattedValue(self: IDataGridViewEditingControl)=value

"""

 EditingControlRowIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the index of the hosting cell's parent row.



Get: EditingControlRowIndex(self: IDataGridViewEditingControl) -> int



Set: EditingControlRowIndex(self: IDataGridViewEditingControl)=value

"""

 EditingControlValueChanged=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the value of the editing control differs from the value of the hosting cell.



Get: EditingControlValueChanged(self: IDataGridViewEditingControl) -> bool



Set: EditingControlValueChanged(self: IDataGridViewEditingControl)=value

"""

 EditingPanelCursor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the cursor used when the mouse pointer is over the System.Windows.Forms.DataGridView.EditingPanel but not over the editing control.



Get: EditingPanelCursor(self: IDataGridViewEditingControl) -> Cursor



"""

 RepositionEditingControlOnValueChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the cell contents need to be repositioned whenever the value changes.



Get: RepositionEditingControlOnValueChange(self: IDataGridViewEditingControl) -> bool



"""


